@@ -235,7 +235,7 @@ GsmApplication::load_settings()
 GsmApplication::GsmApplication()
     : Gtk::Application("org.gnome.SystemMonitor", Gio::APPLICATION_HANDLES_COMMAND_LINE),
       tree(NULL),
-      proc_toolbar_revealer(NULL),
+      proc_actionbar_revealer(NULL),
       popup_menu(NULL),
       disk_list(NULL),
       stack(NULL),
@@ -385,21 +385,6 @@ GsmApplication::shutdown()
     quit();
 }
 
-static void
-load_custom_css ()
-{
-    GFile *css_file = g_file_new_for_uri ("resource:///org/gnome/gnome-system-monitor/data/gsm.css");
-    GtkCssProvider *css_provider = gtk_css_provider_new ();
-
-    gtk_css_provider_load_from_file (css_provider, css_file, NULL);
-    gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-                                               GTK_STYLE_PROVIDER (css_provider),
-                                               GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-
-    g_object_unref (css_file);
-    g_object_unref (css_provider);
-}
-
 void GsmApplication::on_startup()
 {
     Gtk::Application::on_startup();
@@ -443,8 +428,6 @@ void GsmApplication::on_startup()
 
     load_settings ();
 
-    load_custom_css ();
-
     pretty_table = new PrettyTable();
     smooth_refresh = new SmoothRefresh(settings);
 
